#!/usr/bin/env bash
#abyss pipeline configuration file

##############################################
#MAIN PARAMETERS
##############################################

# This datawork is your home directory
DATAWORK=/home2/datawork/btrouche/16S_Med_Atl

#Locus to be analysed (16S-fuhrman or 16S-archaea, COI or 18S-V1 18S-V4 or 18S-V9)
export locus=16S-fuhrman
echo "Barcode locus = $locus"

# OUTPUT DIR WITH RESULTS
export output_dir=$DATAWORK/2_operation
echo "Output directory for Abyss pipeline = $output_dir"
export ligation_preprocess_dir=${output_dir}/0_ligation_preprocess
export cutadapt_dir=${output_dir}/1_cutadapt
export cleaning_dir=${output_dir}/2_R1R2
export dada_dir=${output_dir}/4_dada
export blast_dir=${output_dir}/6_blast

#dada2 merge ASVs tables located in a specific input directory
#Warning : input_merge is the folder containing the ASV tables to merge 
export input_merge=${output_dir}/Final_merged_table
# in case you run dada2mergeasv alone uncomment the export dada_dir
export output_merge=${output_dir}/Final_merged_table

# PIPELINE MAIN DIRECTORY
#Path to abyss-pipeline local git cloned repository
export main_dir=$DATAWORK/abyss-pipeline

#pbs scripts dir
export pbs_dir=$main_dir/pbs

#R python and sh scripts 
export scripts_dir=$main_dir/commun

# reference databases folder
export ref_dir=$DATAWORK/sequence-set-nucleic-acid/tools-data/

#######################################################
##PIPELINE STEPS TO RUN
#######################################################
#abyss-preprocessing pipeline if input reads need to be preprocessed (cleaning process included)
export ligation_preprocess=no

#cleaning (only if input data are not ligation data)
export cleaning_process=no

#dada2
export dada_main_process=no
#merge process only : ASV tables to merge are in the folder input_merge, the result will be written in folder output_merge
export dada_mergeasv_process=yes

#blast assignation (out of frogs)
export blast_assignation=no

#frogs
export frogs_process=no
export extract_amplicons=no
export frogs_only=no

# these steps must be run alone
#tag switching normalisation
export tag_switching_norm_process=no

#lulu curation
export lulu_process=no

#######################################################
##LIGATION PROCESS
#######################################################
# input data are ligation-based  (R1F/R2R and R2F/R1R)
export ligation=yes


#######################################################
#DADA MAIN PROCESS
#######################################################
if [ ${dada_main_process} == "yes" ] || [ ${blast_assignation} == "yes" ]; then
    export script_dada=${scripts_dir}/dada2main.R
    export script_dadamerge=${scripts_dir}/dada2mergeasv.R
    export script_dada2output=${scripts_dir}/dada2outputfiles.R
    # Parameters Dada: target amplicon lengths
    if [ "$locus" = "16S-fuhrman" ]; then
        export lengthMin=350
        export lengthMax=390
        export rdpbank="$ref_dir/silva_nr99_v138_wSpecies_train_set.fa.gz"
    fi
fi

#######################################################
#DADA MERGE ASV
#######################################################
if [ ${dada_mergeasv_process} == "yes" ]; then
    export script_dadamerge=${scripts_dir}/dada2mergeasv.R
    export script_dada2output=${scripts_dir}/dada2outputfiles.R
    # be careful to check the minimum bootstrap value used to assign taxonomy in dada2ouputfiles.R, it should be 80
    export rdpbank="$ref_dir/silva_nr99_v138_wSpecies_train_set.fa.gz"
    #echo "Dada2 merge asv tables script path = $script_dadamerge"
fi
